@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::2_0::Direct::Nodes;
-$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '6.801';use Moo;
 with 'Search::Elasticsearch::Client::2_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('nodes');
@@ -17,7 +18,7 @@ Search::Elasticsearch::Client::2_0::Direct::Nodes - A client for running node-le
 
 =head1 VERSION
 
-version 6.80
+version 6.80_1
 
 =head1 DESCRIPTION
 
