@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::2_0::Role::Scroll;
-$Search::Elasticsearch::Client::2_0::Role::Scroll::VERSION = '6.80';
-use Moo::Role;
+$Search::Elasticsearch::Client::2_0::Role::Scroll::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::2_0::Role::Scroll::VERSION = '6.801';use Moo::Role;
 requires 'finish';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Devel::GlobalDestruction;
@@ -64,7 +65,7 @@ Search::Elasticsearch::Client::2_0::Role::Scroll - Provides common functionality
 
 =head1 VERSION
 
-version 6.80
+version 6.80_1
 
 =head1 AUTHOR
 
